#include <FastLED.h>
#include <Wire.h>
#include <RTClib.h>

#define LED_PIN 7 // Sets our LED strip to pin 7 (depends on which digital pin you choose for your Arduino) 
#define LED_COUNT 21 // Sets the LED count, ie how many lights you want to turn on in your strip
CRGB leds[LED_COUNT];

RTC_PCF8523 rtc; // Declares our RTC object. UPDATE to your RTC module. 

char daysOfTheWeek[7][12] = {
  "Sunday",
  "Monday",
  "Tuesday",
  "Wednesday",
  "Thursday",
  "Friday",
  "Saturday"
};

// Function to update the entire LED strip 
void setLEDColor(int r, int g, int b) {
  for (int j = 0; j < LED_COUNT; j++) {
    leds[j] = CRGB(r, g, b);
  }
  FastLED.show();
}

void setup() {
  delay(1000); // Delay for stability 
  
  Serial.begin(9600); // Begins our serial connection

#ifndef ESP8266
  while (!Serial); // Wait for serial port to connect
#endif

  // This tests to make sure that our RTC is connected
  if (!rtc.begin()) {
    Serial.println("Couldn't find RTC");
    Serial.flush();
    while (1) delay(10);
  } 

// IMPORTANT LINE BELOW: 
// rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));  // Run ONCE with this line, then comment out and reupload your code

  FastLED.addLeds<NEOPIXEL, LED_PIN>(leds, LED_COUNT);
  FastLED.clear(); 
  FastLED.show(); // this line flashes 

// RGB color for LEDs in the strip. This is a bright white. 
  setLEDColor(255, 245, 220);
}

void loop() {
  DateTime now = rtc.now(); // Collects the current time

  // Prints the date and time to the serial monitor every time it loops. 
  Serial.print("Date & Time: ");
  Serial.print(now.year(), DEC);
  Serial.print('/');
  Serial.print(now.month(), DEC);
  Serial.print('/');
  Serial.print(now.day(), DEC);
  Serial.print(" (");
  Serial.print(daysOfTheWeek[now.dayOfTheWeek()]);
  Serial.print(") ");
  Serial.print(now.hour(), DEC);
  Serial.print(':');
  Serial.print(now.minute(), DEC);
  Serial.print(':');
  Serial.println(now.second(), DEC);

  int hh = now.hour(); // Applies current hour to a variable
  int mm = now.minute(); // Applies current minute to a variable
  int ss = now.second(); // Applies current second to a variable

  int bright = mm * 4 + ss/15 + 1; // Brightness increases by 1 every 15 seconds, up to a brightness of 245 (max 255) 
  int dark = 245 - bright; // Gets dark at the same rate, down to almost no brightness
  
  int time_start = 10; // Time to initially turn on LEDs
  int time_max = time_start + 1; // Time when LEDs are completely on 
  int time_dark = 19; // Time when LEDs start to dim
  int time_min = time_dark + 1; // Time when LEDs are completely off 

  // Each case prints the brightness to the serial monitor 
  if ((hh >= time_start) && (hh < time_max)) { // Between 10am and 11am
    FastLED.setBrightness(bright); // slowly increase brightness
    Serial.println(bright); 
  }

  if ((hh >= time_max) && (hh < time_dark)) { // Between 11am and 7pm 
    FastLED.setBrightness(245); // if "bright" variable changes, make sure this value is set to its maximum value 
    Serial.println("max brightness");
  }

  if ((hh >= time_dark) && (hh < time_min)) { // Between 7pm and 8pm
    FastLED.setBrightness(dark); 
    Serial.println(dark);
  }

  if ((hh >= time_min) || (hh < time_start)) { // Between 8pm and 10am
    FastLED.setBrightness(0); 
    Serial.println("off");
  }

  FastLED.show(); // Updates LEDs with settings above
  
  delay(1000); // Delay for stability
}
